@@ -1,33 +1,47 @@
+################################################################################
+##
+## $Id: AllGenerics.R 1150 2007-08-24 15:15:32Z suo $
+##
+## Generic Methods
+##
+################################################################################
 
 ## tradeCostsResults class methods
 
-if(!isGeneric("pdfSummary"))
-  setGeneric("pdfSummary",              
-             function(object,
-                      ...) standardGeneric("pdfSummary"))
 
 
+if(!isGeneric("pdf"))
+  setGeneric("pdf",              
+             function(object,
+                      ...) standardGeneric("pdf"))
+
+if(!isGeneric("calc"))
+  setGeneric("calc",              
+             function(object,
+                      by,
+                      ...) standardGeneric("calc"))
+
 if(!isGeneric("calcAll"))
   setGeneric("calcAll",              
-             function(results,
+             function(batches,
                       num.trades,
                       ...) standardGeneric("calcAll"))
 
 if(!isGeneric("calcID"))
   setGeneric("calcID",              
-             function(results,
+             function(batches,
                       num.trades,
                       ...) standardGeneric("calcID"))
 
 if(!isGeneric("calcPeriod"))
   setGeneric("calcPeriod",              
-             function(results,
+             function(batches,
                       num.trades,
                       ...) standardGeneric("calcPeriod"))
 
 if(!isGeneric("calcStats"))
   setGeneric("calcStats",              
-             function(results,
+             function(batches,
                       ...) standardGeneric("calcStats"))
 
 ## tradeCosts class methods
@@ -35,6 +49,5 @@ if(!isGeneric("calcStats"))
 if(!isGeneric("analyzeData"))
   setGeneric("analyzeData",
              function(object,
-                      base.price,
-                      benchmark.price,
                       ...) standardGeneric("analyzeData"))
+
